var TokenProcessor = /** @class */ (function () {
    function TokenProcessor(code, tokens) {
        this.code = code;
        this.tokens = tokens;
        this.resultCode = '';
        this.tokenIndex = 0;
    }
    TokenProcessor.prototype.reset = function () {
        this.resultCode = '';
        this.tokenIndex = 0;
    };
    TokenProcessor.prototype.matchesAtIndex = function (index, tagLabels) {
        if (index < 0) {
            return false;
        }
        for (var i = 0; i < tagLabels.length; i++) {
            if (index + i >= this.tokens.length) {
                return false;
            }
            if (this.tokens[index + i].type.label !== tagLabels[i]) {
                return false;
            }
        }
        return true;
    };
    TokenProcessor.prototype.matchesNameAtIndex = function (index, name) {
        return this.matchesAtIndex(index, ['name']) && this.tokens[index].value === name;
    };
    TokenProcessor.prototype.matches = function (tagLabels) {
        return this.matchesAtIndex(this.tokenIndex, tagLabels);
    };
    TokenProcessor.prototype.matchesName = function (name) {
        return this.matchesNameAtIndex(this.tokenIndex, name);
    };
    TokenProcessor.prototype.previousWhitespace = function () {
        return this.code.slice(this.tokenIndex > 0
            ? this.tokens[this.tokenIndex - 1].end
            : 0, this.tokens[this.tokenIndex].start);
    };
    TokenProcessor.prototype.replaceToken = function (newCode) {
        this.resultCode += this.previousWhitespace();
        this.resultCode += newCode;
        this.tokenIndex++;
    };
    TokenProcessor.prototype.replaceTokenTrimmingLeftWhitespace = function (newCode) {
        this.resultCode += this.previousWhitespace().replace(/[\t ]/g, '');
        this.resultCode += newCode;
        this.tokenIndex++;
    };
    TokenProcessor.prototype.removeInitialToken = function () {
        this.replaceToken('');
    };
    TokenProcessor.prototype.removeToken = function () {
        this.replaceTokenTrimmingLeftWhitespace('');
    };
    TokenProcessor.prototype.copyExpectedToken = function (label) {
        if (this.tokens[this.tokenIndex].type.label !== label) {
            throw new Error("Expected token " + label);
        }
        this.copyToken();
    };
    TokenProcessor.prototype.copyToken = function () {
        this.resultCode += this.code.slice(this.tokenIndex > 0
            ? this.tokens[this.tokenIndex - 1].end
            : 0, this.tokens[this.tokenIndex].end);
        this.tokenIndex++;
    };
    TokenProcessor.prototype.appendCode = function (code) {
        this.resultCode += code;
    };
    TokenProcessor.prototype.currentToken = function () {
        return this.tokens[this.tokenIndex];
    };
    TokenProcessor.prototype.currentIndex = function () {
        return this.tokenIndex;
    };
    TokenProcessor.prototype.finish = function () {
        if (this.tokenIndex !== this.tokens.length) {
            throw new Error('Tried to finish processing tokens before reaching the end.');
        }
        this.resultCode += this.code.slice(this.tokens[this.tokens.length - 1].end);
        return this.resultCode;
    };
    TokenProcessor.prototype.isAtEnd = function () {
        return this.tokenIndex === this.tokens.length;
    };
    return TokenProcessor;
}());
export default TokenProcessor;
