#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var babel = require("babel-core");
// Use require rather than import to hack around missing type info.
var buble = require('buble');
var sucrase = require("../src/index");
var TypeScript = require("typescript");
function main() {
    console.log('Simulating transpilation of 100,000 lines of code:');
    var code = fs.readFileSync('./benchmark/sample.js').toString();
    runBenchmark('Sucrase', function () { return sucrase.transform(code, { transforms: ['jsx', 'imports', 'add-module-exports', 'react-display-name'] }); });
    runBenchmark('Buble (JSX, no import transform)', function () {
        return buble.transform(code, { transforms: { modules: false } });
    });
    runBenchmark('TypeScript', function () {
        return TypeScript.transpileModule(code, {
            compilerOptions: {
                module: TypeScript.ModuleKind.CommonJS,
                jsx: TypeScript.JsxEmit.React,
                target: TypeScript.ScriptTarget.ESNext
            }
        });
    });
    runBenchmark('Babel', function () { return babel.transform(code, { presets: ['react'], plugins: ['transform-es2015-modules-commonjs'] }); });
}
function runBenchmark(name, runTrial) {
    // Run twice before starting the clock to warm up the JIT, caches, etc.
    runTrial();
    runTrial();
    console.time(name);
    for (var i = 0; i < 100; i++) {
        runTrial();
    }
    console.timeEnd(name);
}
if (require.main === module) {
    main();
}
